EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Applications_EditApplication',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Edits an existing application.'
GO


IF OBJECT_ID('[Applications_EditApplication]') IS NOT NULL DROP PROCEDURE [Applications_EditApplication]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Applications_EditApplication]
(
	@Application_Id INT,
	@Application_Name VARCHAR(50),
	@Application_Description VARCHAR(MAX),
	@ApplicationGroup_Id INT,
	@AllowMultipleActiveReleases_Indicator YNINDICATOR = NULL,
	@AllowMultipleActiveBuilds_Indicator YNINDICATOR = NULL,
	@VariableSupport_Code CHAR(1) = NULL,
    @ReleaseNumber_Scheme_Name VARCHAR(20) = NULL,
	@BuildNumber_Scheme_Name VARCHAR(15) = NULL,
	@ApplicationConfiguration_Xml XML = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [Applications]
       SET [Application_Name] = @Application_Name
		  ,[Application_Description] = @Application_Description
		  ,[ApplicationGroup_Id] = @ApplicationGroup_Id
		  ,[AllowMultipleActiveBuilds_Indicator] = COALESCE(@AllowMultipleActiveBuilds_Indicator, [AllowMultipleActiveBuilds_Indicator])
		  ,[ModifiedBy_User_Name] = [dbo].[Session_GetUserName]()
		  ,[ModifiedOn_Date] = GETUTCDATE()
		  ,[VariableSupport_Code] = COALESCE(@VariableSupport_Code, [VariableSupport_Code])
          ,[ReleaseNumber_Scheme_Name] = COALESCE(@ReleaseNumber_Scheme_Name, [ReleaseNumber_Scheme_Name])
		  ,[BuildNumber_Scheme_Name] = COALESCE(@BuildNumber_Scheme_Name, [BuildNumber_Scheme_Name])
		  ,[ApplicationConfiguration_Xml] = COALESCE(@ApplicationConfiguration_Xml, [ApplicationConfiguration_Xml])
     WHERE [Application_Id] = @Application_Id
	IF @@ROWCOUNT=0 RAISERROR('Application %i does not exist.',16,1, @Application_Id)

	/* Raise Event */
	EXEC [Events_RaiseEvent] 'APPMOD',@Application_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0  ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Applications_EditApplication] TO [BuildMasterUser_Role]
