EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_PurgeBuildData',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Purges an entire build and all associated data from the system.'
GO

IF OBJECT_ID('[Builds_PurgeBuildData]') IS NOT NULL DROP PROCEDURE [Builds_PurgeBuildData]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_PurgeBuildData]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Build_Id INT
	DECLARE @Release_Id INT
	DECLARE @Application_Name VARCHAR(50)
	SELECT @Build_Id = B.[Build_Id],
	       @Release_Id = B.[Release_Id],
	       @Application_Name = A.[Application_Name]
	  FROM [Builds] B
	       INNER JOIN [Releases] R
		           ON R.[Release_Id] = B.[Release_Id]
		   INNER JOIN [Applications] A
		           ON A.[Application_Id] = R.[Application_Id]
	 WHERE A.[Application_Id] = @Application_Id
           AND R.[Release_Number] = @Release_Number
           AND B.[Build_Number] = @Build_Number
          

	DECLARE @Promotions TABLE ([Promotion_Id] INT NOT NULL)
	INSERT INTO @Promotions
	SELECT [Promotion_Id]
	  FROM [BuildPromotions]
	 WHERE [Build_Id] = @Build_Id

	DECLARE @Executions TABLE ([Execution_Id] INT NOT NULL)
	INSERT INTO @Executions ([Execution_Id])
	SELECT [Execution_Id]
	  FROM [BuildExecutions]
	 WHERE [Promotion_Id] IN (SELECT [Promotion_Id] FROM @Promotions)

	DELETE [ReleaseNotes]
	 WHERE [Build_Id] = @Build_Id

	DELETE [VariableDefinitions]
	 WHERE [Build_Id] = @Build_Id
	    OR [Promotion_Id] IN (SELECT [Promotion_Id] FROM @Promotions)
		OR [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildArtifacts]
	 WHERE [Build_Id] = @Build_Id

    DELETE [BuildPromotionsScheduled]
	 WHERE [Build_Id] = @Build_Id

	DECLARE @BuildExecution_DeploymentPlans TABLE ([BuildExecution_DeploymentPlan_Id] INT NOT NULL)
	INSERT INTO @BuildExecution_DeploymentPlans ([BuildExecution_DeploymentPlan_Id])
	SELECT [BuildExecution_DeploymentPlan_Id]
	  FROM [BuildExecution_DeploymentPlans]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DECLARE @BuildExecution_ActionGroupActions TABLE ([BuildExecution_ActionGroupAction_Id] INT NOT NULL)
	INSERT INTO @BuildExecution_ActionGroupActions ([BuildExecution_ActionGroupAction_Id])
	SELECT [BuildExecution_ActionGroupAction_Id]
	  FROM [BuildExecution_ActionGroupActions]
	 WHERE [BuildExecution_DeploymentPlan_Id] IN (SELECT [BuildExecution_DeploymentPlan_Id] FROM @BuildExecution_DeploymentPlans)

	DELETE [BuildTestResults]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildOutputs]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildExecution_ActionGroupActionLogEntries]
	 WHERE [BuildExecution_ActionGroupAction_Id] IN (SELECT [BuildExecution_ActionGroupAction_Id] FROM @BuildExecution_ActionGroupActions)

    DELETE [BuildExecution_ActionGroupActionVariableValues]
	 WHERE [BuildExecution_ActionGroupAction_Id] IN (SELECT [BuildExecution_ActionGroupAction_Id] FROM @BuildExecution_ActionGroupActions)

	DELETE [ManualActionsInProgress]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildExecution_ActionGroupActions]
	 WHERE [BuildExecution_ActionGroupAction_Id] IN (SELECT [BuildExecution_ActionGroupAction_Id] FROM @BuildExecution_ActionGroupActions)

	DELETE [BuildExecution_DeploymentPlanActionGroups]
	 WHERE [BuildExecution_DeploymentPlan_Id] IN (SELECT [BuildExecution_DeploymentPlan_Id] FROM @BuildExecution_DeploymentPlans)

	UPDATE [Executions]
	   SET [DependentUpon_Execution_Id] = NULL
	 WHERE [DependentUpon_Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	UPDATE [BuildExecutions]
	   SET [Initial_BuildExecution_DeploymentPlan_Id] = NULL
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildExecution_DeploymentPlans]
	 WHERE [BuildExecution_DeploymentPlan_Id] IN (SELECT [BuildExecution_DeploymentPlan_Id] FROM @BuildExecution_DeploymentPlans)

	DELETE [DatabaseChangeScriptExecutions]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [ScopedExecutionLogEntries]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [ScopedExecutionLogs]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildExecutions]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE [BuildPromotions]
	 WHERE [Promotion_Id] IN (SELECT [Promotion_Id] FROM @Promotions)

	DELETE [Builds]
	 WHERE [Build_Id] = @Build_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END


GO

GRANT EXECUTE ON [Builds_PurgeBuildData] TO [BuildMasterUser_Role]
