EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Builds_PurgeExecutionLogs',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'LogMessagesDeleted_Count',
    /* Description_Text        */ 'Purges execution logs in a specific build before a specified time.'
GO

IF OBJECT_ID('[Builds_PurgeExecutionLogs]') IS NOT NULL DROP PROCEDURE [Builds_PurgeExecutionLogs]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Builds_PurgeExecutionLogs]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER,
	@Environment_Id INT,
	@PipelineStage_Name VARCHAR(50),
	@Before_Date DATETIME,
	@LogMessagesDeleted_Count BIGINT = NULL OUT
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @ToDelete TABLE ([Execution_Id] INT NOT NULL)

	INSERT INTO @ToDelete
	SELECT BE.[Execution_Id]
	  FROM [BuildExecutions] BE
		   INNER JOIN [BuildPromotions] BP
		           ON BP.[Promotion_Id] = BE.[Promotion_Id]
		   INNER JOIN [Builds] B
			       ON B.[Build_Id] = BP.[Build_Id]
		   INNER JOIN [Releases] R
			       ON R.[Release_Id] = B.[Release_Id]
		   INNER JOIN [Executions] E
		           ON E.[Execution_Id] = BE.[Execution_Id]
	 WHERE R.[Application_Id] = @Application_Id
	   AND R.[Release_Number] = @Release_Number
	   AND B.[Build_Number] = @Build_Number
	   AND (@Environment_Id IS NULL OR BE.[Environment_Id] = @Environment_Id)
	   AND (@PipelineStage_Name IS NULL OR BP.[PipelineStage_Name] = @PipelineStage_Name)
	   AND (@Before_Date IS NULL OR E.[End_Date] < @Before_Date)

	UPDATE [Executions]
	   SET [DependentUpon_Execution_Id] = NULL
	 WHERE [DependentUpon_Execution_Id] IN (SELECT [Execution_Id] FROM @ToDelete)

	DELETE BEAGALE
	  FROM [BuildExecution_ActionGroupActionLogEntries] BEAGALE
	       INNER JOIN [BuildExecution_ActionGroupActions] BEAGA
		           ON BEAGA.[BuildExecution_ActionGroupAction_Id] = BEAGALE.[BuildExecution_ActionGroupAction_Id]
	       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
		           ON BEDP.[BuildExecution_DeploymentPlan_Id] = BEAGA.[BuildExecution_DeploymentPlan_Id]
	 WHERE BEDP.[Execution_Id] IN (SELECT [Execution_Id] FROM @ToDelete)

	SET @LogMessagesDeleted_Count = ROWCOUNT_BIG()

	DELETE
	  FROM [ScopedExecutionLogs]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @ToDelete)

	SET @LogMessagesDeleted_Count = @LogMessagesDeleted_Count + ROWCOUNT_BIG()

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Builds_PurgeExecutionLogs] TO [BuildMasterUser_Role]
