EXEC [__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Issues_GetIssues',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Issues_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the issues for an application, optionally filtered by release or build.'
GO


IF OBJECT_ID('[Issues_GetIssues]') IS NOT NULL DROP PROCEDURE [Issues_GetIssues]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Issues_GetIssues]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER = NULL,
    @Build_Number BUILDNUMBER = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	SELECT IE.*
	  FROM [Issues_Extended] IE
 LEFT JOIN [Builds] B
        ON B.[Release_Id] = IE.[Release_Id]
       AND B.[Build_Number] = @Build_Number
	 WHERE (@Application_Id IS NULL OR IE.[Application_Id] = @Application_Id)
	   AND (@Release_Number IS NULL OR IE.[Release_Number] = @Release_Number)
       AND (@Build_Number IS NULL OR (IE.[OpenedOn_Original_Build_Sequence] IS NULL AND IE.[ClosedOn_Original_Build_Sequence] IS NOT NULL) OR B.[Build_Sequence] >= IE.[OpenedOn_Original_Build_Sequence])
       AND (@Build_Number IS NULL OR IE.[ClosedOn_Original_Build_Sequence] IS NULL OR B.[Build_Sequence] = IE.[ClosedOn_Original_Build_Sequence])
  ORDER BY [Application_Name], [Release_Sequence] DESC, [Closed_Indicator], [Issue_Id] DESC

END
GO

GRANT EXECUTE ON [Issues_GetIssues] TO [BuildMasterUser_Role]
