EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'LegacyExecutions_GetPartialExecutionLog',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'BuildExecution_ActionGroupActionLogEntries',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the latest log entries for a specified build execution.'
GO

IF OBJECT_ID('[LegacyExecutions_GetPartialExecutionLog]') IS NOT NULL DROP PROCEDURE [LegacyExecutions_GetPartialExecutionLog]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [LegacyExecutions_GetPartialExecutionLog]
(
	@Execution_Id INT,
    @After_BuildExecution_ActionGroupAction_Id INT,
	@After_LogEntry_Sequence INT,
    @IncludeDebug_Indicator YNINDICATOR
)
AS
BEGIN

	SET NOCOUNT ON

    SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED

		SELECT BEAGALE.*
		  FROM [BuildExecution_ActionGroupActionLogEntries] BEAGALE
		       INNER JOIN [BuildExecution_ActionGroupActions] BEAGA
		               ON BEAGA.[BuildExecution_ActionGroupAction_Id] = BEAGALE.[BuildExecution_ActionGroupAction_Id]
		       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
		               ON BEDP.[BuildExecution_DeploymentPlan_Id] = BEAGA.[BuildExecution_DeploymentPlan_Id]
			   INNER JOIN [BuildExecutions] BE
			           ON BE.[Execution_Id] = BEDP.[Execution_Id]
			   INNER JOIN [BuildPromotions] BP
			           ON BP.[Promotion_Id] = BE.[Promotion_Id]
			   INNER JOIN [Builds] B
			           ON B.[Build_Id] = BP.[Build_Id]
		 WHERE BEDP.[Execution_Id] = @Execution_Id
		   AND (@IncludeDebug_Indicator = 'Y' OR BEAGALE.[LogEntry_Level] > 0)
		   AND (BEAGA.[Original_Action_Sequence] > 0)
		   AND (@After_BuildExecution_ActionGroupAction_Id IS NULL
		        OR (BEAGALE.[BuildExecution_ActionGroupAction_Id] > @After_BuildExecution_ActionGroupAction_Id)
		        OR (BEAGALE.[BuildExecution_ActionGroupAction_Id] = @After_BuildExecution_ActionGroupAction_Id
		            AND (@After_LogEntry_Sequence IS NULL OR BEAGALE.[LogEntry_Sequence] > @After_LogEntry_Sequence)))
		 ORDER BY BEAGALE.[BuildExecution_ActionGroupAction_Id]

END
GO

GRANT EXECUTE ON [LegacyExecutions_GetPartialExecutionLog] TO [BuildMasterUser_Role]
