EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_CloneDeploymentPlans',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'NewDeploymentPlanIdsCsv',
    /* Description_Text        */ 'Clones one or more deployment plans'
GO

IF OBJECT_ID('[Plans_CloneDeploymentPlans]') IS NOT NULL
	DROP PROCEDURE [Plans_CloneDeploymentPlans]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_CloneDeploymentPlans]
(
	@DeploymentPlanCloneData_Xml XML,
	@NewDeploymentPlanIdsCsv VARCHAR(MAX) = NULL OUT
) AS
BEGIN
	/*<DeploymentPlanCloneData LinkAllActionGroups_Indicator="Y">
        <DeploymentPlan>
          <New_DeploymentPlan_Name>Standard</New_DeploymentPlan_Name>
          <DeploymentPlan_Id>3</DeploymentPlan_Id>
          <Sequence>1000</Sequence>
        </DeploymentPlan>
	  </DeploymentPlanCloneData>*/

SET NOCOUNT ON

BEGIN TRY

	BEGIN TRANSACTION

		DECLARE @LinkAllActionGroups_Indicator YNINDICATOR
		    SET @LinkAllActionGroups_Indicator =
		       (SELECT DPCD.[value]('@LinkAllActionGroups_Indicator', 'CHAR(1)')
	              FROM @DeploymentPlanCloneData_Xml.[nodes]('/DeploymentPlanCloneData') AS DeploymentPlanCloneData(DPCD))

		DECLARE @Sequenced_DeploymentPlans TABLE ([Old_DeploymentPlan_Id] INT, [Seq] INT)

        INSERT @Sequenced_DeploymentPlans ([Old_DeploymentPlan_Id], [Seq])
        SELECT DPCD.[value]('DeploymentPlan_Id[1]', 'INT') [Old_DeploymentPlan_Id],
               DPCD.[value]('Sequence[1]', 'INT') [Seq]
          FROM @DeploymentPlanCloneData_Xml.[nodes]('/DeploymentPlanCloneData/DeploymentPlan') AS DeploymentPlanCloneData(DPCD)
        

        DECLARE @DeploymentPlans TABLE ([Old_DeploymentPlan_Id] INT, [New_DeploymentPlan_Id] INT, [AllowLocalChanges_Indicator] CHAR(1), [New_DeploymentPlan_Name] VARCHAR(50), [Seq] INT)

        INSERT INTO @DeploymentPlans ([Old_DeploymentPlan_Id], [New_DeploymentPlan_Name], [AllowLocalChanges_Indicator])
		SELECT DISTINCT [Old_DeploymentPlan_Id], [New_DeploymentPlan_Name], [AllowLocalChanges_Indicator]
		  FROM (SELECT DPCD.[value]('New_DeploymentPlan_Name[1]', 'VARCHAR(20)') [New_DeploymentPlan_Name],
					   DPCD.[value]('DeploymentPlan_Id[1]', 'INT') [Old_DeploymentPlan_Id]
				  FROM @DeploymentPlanCloneData_Xml.[nodes]('/DeploymentPlanCloneData/DeploymentPlan') AS DeploymentPlanCloneData(DPCD)) DPCD
			   INNER JOIN [DeploymentPlans] DP ON DP.[DeploymentPlan_Id] = DPCD.[Old_DeploymentPlan_Id]

		DECLARE @ActionGroups TABLE ([Old_ActionGroup_Id] INT, [New_ActionGroup_Id] INT, [Old_DeploymentPlan_Id] INT, [Old_DeploymentPlanActionGroup_Sequence] INT)

		IF @LinkAllActionGroups_Indicator = 'Y' BEGIN
			
			INSERT INTO @ActionGroups ([Old_ActionGroup_Id], [New_ActionGroup_Id], [Old_DeploymentPlan_Id], [Old_DeploymentPlanActionGroup_Sequence])
			SELECT  AG.[ActionGroup_Id], 
					AG.[ActionGroup_Id], 
					DPAG.[DeploymentPlan_Id],
                    DPAG.[DeploymentPlanActionGroup_Sequence]
			  FROM [ActionGroups] AG
				   INNER JOIN [DeploymentPlanActionGroups] DPAG
						   ON AG.[ActionGroup_Id] = DPAG.[ActionGroup_Id]
				   INNER JOIN @DeploymentPlans DP
						   ON DP.[Old_DeploymentPlan_Id] = DPAG.[DeploymentPlan_Id]

		END ELSE BEGIN 

			INSERT INTO @ActionGroups ([Old_ActionGroup_Id], [Old_DeploymentPlan_Id], [Old_DeploymentPlanActionGroup_Sequence])
		    SELECT  AG.[ActionGroup_Id],
                    DPAG.[DeploymentPlan_Id],
                    DPAG.[DeploymentPlanActionGroup_Sequence]
			  FROM [ActionGroups] AG
				   INNER JOIN [DeploymentPlanActionGroups] DPAG
						   ON AG.[ActionGroup_Id] = DPAG.[ActionGroup_Id]
				   INNER JOIN @DeploymentPlans DP
						   ON DP.[Old_DeploymentPlan_Id] = DPAG.[DeploymentPlan_Id]
		
			DECLARE @ActionGroupsOldId INT
			DECLARE @ActionGroupsInsertCur CURSOR
			   SET @ActionGroupsInsertCur = CURSOR FOR 
				SELECT [Old_ActionGroup_Id] FROM @ActionGroups
					FOR UPDATE OF [New_ActionGroup_Id]
			OPEN @ActionGroupsInsertCur
			FETCH NEXT FROM @ActionGroupsInsertCur INTO @ActionGroupsOldId
			WHILE @@FETCH_STATUS = 0 
			BEGIN

				INSERT INTO [ActionGroups] 
				(
					[CreatedBy_User_Name],[CreatedOn_Date],[ModifiedBy_User_Name],[ModifiedOn_Date],
					[ActionGroup_Name],[Predicate_Configuration],[ActionGroup_Description],
					[Server_Id],[Server_Variable_Name]
				)
				SELECT	
					dbo.Session_GetUserName(), GETUTCDATE(), [ModifiedBy_User_Name],[ModifiedOn_Date],
					[ActionGroup_Name],[Predicate_Configuration],[ActionGroup_Description],
					[Server_Id],[Server_Variable_Name]   
				FROM [ActionGroups] 
				WHERE [ActionGroup_Id] = @ActionGroupsOldId

				UPDATE @ActionGroups SET [New_ActionGroup_Id] = SCOPE_IDENTITY()
				 WHERE CURRENT OF @ActionGroupsInsertCur
			
				FETCH NEXT FROM @ActionGroupsInsertCur INTO @ActionGroupsOldId
			END
			CLOSE @ActionGroupsInsertCur


			--==[ActionGroupActions]==--
			INSERT INTO [ActionGroupActions] (
				   [ActionGroup_Id]
				  ,[Action_Sequence]
				  ,[Server_Id]
				  ,[Long_Description]
				  ,[ResumeNextOnFailure_Indicator]
				  ,[Action_Configuration]
				  ,[Short_Description]
				  ,[Active_Indicator]
				  ,[Retry_Count]
				  ,[LogFailureAsWarning_Indicator]
				  ,[Server_Variable_Name]
				  ,[Target_Server_Id]
				  ,[Target_Server_Variable_Name]
				  ,[ExtensionConfiguration_Id]
			) SELECT 
				   [New_ActionGroup_Id]
				  ,[Action_Sequence]
				  ,[Server_Id]
				  ,[Long_Description]
				  ,[ResumeNextOnFailure_Indicator]
				  ,[Action_Configuration]
				  ,[Short_Description]
				  ,[Active_Indicator]
				  ,[Retry_Count]
				  ,[LogFailureAsWarning_Indicator]
				  ,[Server_Variable_Name]
				  ,[Target_Server_Id]
				  ,[Target_Server_Variable_Name]
				  ,[ExtensionConfiguration_Id]
			  FROM [ActionGroupActions] JOIN @ActionGroups ON [ActionGroup_Id] = [Old_ActionGroup_Id]
		END

		--==[DeploymentPlans]==--
		DECLARE @DeploymentPlansNewId INT, @DeploymentPlansNewName VARCHAR(50), @AllowLocalChanges_Indicator CHAR(1)
		DECLARE @DeploymentPlansInsertCur CURSOR
			SET @DeploymentPlansInsertCur = CURSOR FOR 
			SELECT [New_DeploymentPlan_Id], [New_DeploymentPlan_Name], [AllowLocalChanges_Indicator] FROM @DeploymentPlans
				FOR UPDATE OF [New_DeploymentPlan_Id]
		OPEN @DeploymentPlansInsertCur
		FETCH NEXT FROM @DeploymentPlansInsertCur INTO @DeploymentPlansNewId, @DeploymentPlansNewName, @AllowLocalChanges_Indicator
		WHILE @@FETCH_STATUS = 0 
		BEGIN

			INSERT INTO [DeploymentPlans] ([DeploymentPlan_Name], [AllowLocalChanges_Indicator]) VALUES (@DeploymentPlansNewName, @AllowLocalChanges_Indicator)
			
			UPDATE @DeploymentPlans SET [New_DeploymentPlan_Id] = SCOPE_IDENTITY()
				WHERE CURRENT OF @DeploymentPlansInsertCur

			FETCH NEXT FROM @DeploymentPlansInsertCur INTO @DeploymentPlansNewId, @DeploymentPlansNewName, @AllowLocalChanges_Indicator

		END
		CLOSE @DeploymentPlansInsertCur

		--==[DeploymentPlanActionGroups]==--
		INSERT INTO [DeploymentPlanActionGroups] (
			  /*[DeploymentPlanActionGroup_Id]*/
			  [DeploymentPlan_Id]
			  ,[DeploymentPlanActionGroup_Sequence]
			  ,[ActionGroup_Id]
			  ,[Deployable_Name]
			  ,[Deployable_Application_Id]
			  ,[Active_Indicator]
			  ,[ActionGroup_Name]
			  ,[ActionGroup_Description]
			  ,[Predicate_Configuration]
			  ,[Server_Id]
			  ,[Server_Variable_Name]
			  ,[Iterate_Servers_Indicator]
			  ,[Iterate_Deployables_Indicator]
			  ,[Parallel_Indicator]
			  ,[OnSuccess_DeploymentPlanActionGroup_Id]
			  ,[OnFailure_DeploymentPlanActionGroup_Id]
			  ,[OnFailure_Continue_Indicator]
			  ,[ModifiedBy_User_Name]
			  ,[ModifiedOn_Date]
		) SELECT 
			  [New_DeploymentPlan_Id]
			  ,[DeploymentPlanActionGroup_Sequence]
			  ,[New_ActionGroup_Id]
			  ,[Deployable_Name]
			  ,[Deployable_Application_Id]
			  ,[Active_Indicator]
			  ,[ActionGroup_Name]
			  ,[ActionGroup_Description]
			  ,[Predicate_Configuration]
			  ,[Server_Id]
			  ,[Server_Variable_Name]
			  ,[Iterate_Servers_Indicator]
			  ,[Iterate_Deployables_Indicator]
			  ,[Parallel_Indicator]
			  ,[OnSuccess_DeploymentPlanActionGroup_Id]
			  ,[OnFailure_DeploymentPlanActionGroup_Id]
			  ,[OnFailure_Continue_Indicator]
			  ,[ModifiedBy_User_Name]
			  ,[ModifiedOn_Date]
		  FROM [DeploymentPlanActionGroups] DPAG
         INNER JOIN @ActionGroups AG
                 ON DPAG.[DeploymentPlan_Id] = AG.[Old_DeploymentPlan_Id] 
                AND DPAG.[ActionGroup_Id] = AG.[Old_ActionGroup_Id] 
                AND DPAG.[DeploymentPlanActionGroup_Sequence] = AG.[Old_DeploymentPlanActionGroup_Sequence]
         INNER JOIN @DeploymentPlans DP 
                 ON [DeploymentPlan_Id] = DP.[Old_DeploymentPlan_Id] 
                AND [DeploymentPlanActionGroup_Sequence] = AG.[Old_DeploymentPlanActionGroup_Sequence]

		SELECT @NewDeploymentPlanIdsCsv = ISNULL(@NewDeploymentPlanIdsCsv,'') + CAST([New_DeploymentPlan_Id] AS VARCHAR(MAX)) + ','
		  FROM @DeploymentPlans DP
        INNER JOIN @Sequenced_DeploymentPlans SEQ ON SEQ.Old_DeploymentPlan_Id = DP.Old_DeploymentPlan_Id
         ORDER BY SEQ.[Seq]
		SET @NewDeploymentPlanIdsCsv = SUBSTRING(@NewDeploymentPlanIdsCsv, 1, LEN(@NewDeploymentPlanIdsCsv)-1)

	COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_CloneDeploymentPlans] TO [BuildMasterUser_Role]
GO