EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_CreatePlan',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Plan_Id',
    /* Description_Text        */ 'Creates a new OtterScript deployment plan.'
GO

IF OBJECT_ID('[Plans_CreatePlan]') IS NOT NULL DROP PROCEDURE [Plans_CreatePlan]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_CreatePlan]
(
	@Plan_Name VARCHAR(255),
    @Application_Id INT,
    @Environment_Id INT,
    @PlanType_Code CHAR(1),
    @Plan_Bytes VARBINARY(MAX) = NULL,
	@ModifiedOn_Date DATETIME = NULL,
	@ModifiedBy_User_Name USERNAME = NULL,
	@Active_Indicator YNINDICATOR = NULL,
	@Plan_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    SELECT @Plan_Id = COALESCE(@Plan_Id, [Plan_Id])
      FROM [Plans] 
     WHERE [Plan_Name] = @Plan_Name 
       AND [Application_Id] = @Application_Id
       AND [PlanType_Code] = @PlanType_Code
       AND [Active_Indicator] = 'N'

    IF @Plan_Id IS NOT NULL
    BEGIN

        UPDATE [Plans]
           SET [Active_Indicator] = 'Y',
               [Environment_Id] = @Environment_Id,
               [ModifiedOn_Date] = GETUTCDATE(),
               [ModifiedBy_User_Name] = dbo.Session_GetUserName()
         WHERE [Plan_Id] = @Plan_Id

    END
    ELSE
    BEGIN

	    INSERT INTO [Plans]
	    (
            [Plan_Name],
            [Application_Id],
            [Environment_Id],
            [PlanType_Code],
            [ModifiedOn_Date],
            [ModifiedBy_User_Name],
            [Active_Indicator]
	    )
	    VALUES
	    (
            @Plan_Name,
            @Application_Id,
            @Environment_Id,
            @PlanType_Code,
            COALESCE(@ModifiedOn_Date, GETUTCDATE()),
            COALESCE(@ModifiedBy_User_Name, dbo.Session_GetUserName()),
            COALESCE(@Active_Indicator, 'Y')
	    )

	    SET @Plan_Id = SCOPE_IDENTITY()

    END

    DECLARE @NextPlanVersionId INT

    SELECT @NextPlanVersionId = COALESCE(MAX([PlanVersion_Id]), 0) + 1 
      FROM [PlanVersions]
     WHERE [Plan_Id] = @Plan_Id

    IF @Plan_Bytes IS NOT NULL
    BEGIN
        
        INSERT INTO [PlanVersions] ([PlanVersion_Id], [Plan_Id], [ModifiedOn_Date], [ModifiedBy_User_Name], [Plan_Bytes])
        VALUES (@NextPlanVersionId, @Plan_Id, GETUTCDATE(), dbo.Session_GetUserName(), @Plan_Bytes)

    END

	--EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @Plan_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_CreatePlan] TO [BuildMasterUser_Role]
