EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_UpdateActionGroup',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates the specified action group.'
GO


IF OBJECT_ID('[Plans_UpdateActionGroup]') IS NOT NULL DROP PROCEDURE [Plans_UpdateActionGroup]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_UpdateActionGroup]
(
	@ActionGroup_Id INT,
	@ActionGroup_Name VARCHAR(50),
	@ActionGroup_Description VARCHAR(MAX),
	@Predicate_Configuration XML,
	@Server_Id INT,
	@Server_Variable_Name VARCHAR(50)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Old_Predicate_Configuration XML
	SELECT @Old_Predicate_Configuration = [Predicate_Configuration]
	  FROM [ActionGroups]
	 WHERE [ActionGroup_Id] = @ActionGroup_Id

	UPDATE [ActionGroups]
	   SET [ActionGroup_Name] = NULLIF(@ActionGroup_Name, '')
		  ,[ActionGroup_Description] = NULLIF(@ActionGroup_Description, '')
	      ,[Predicate_Configuration] = @Predicate_Configuration
	      ,[ModifiedOn_Date] = GETUTCDATE()
	      ,[ModifiedBy_User_Name] = dbo.Session_GetUserName()
	      ,[Server_Id] = @Server_Id
	      ,[Server_Variable_Name] = NULLIF(@Server_Variable_Name, '')
	 WHERE [ActionGroup_Id] = @ActionGroup_Id

	DECLARE @Plans TABLE ([DeploymentPlan_Id] INT)
	INSERT INTO @Plans
	SELECT DISTINCT([DeploymentPlan_Id])
	  FROM [DeploymentPlanActionGroups]
	 WHERE [ActionGroup_Id] = @ActionGroup_Id
 
	WHILE ((SELECT COUNT(*) FROM @Plans) > 0)
	BEGIN

		DECLARE @DeploymentPlan_Id INT
		SET @DeploymentPlan_Id = (SELECT TOP 1 [DeploymentPlan_Id] FROM @Plans)
		DELETE @Plans WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id

		EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id

	END

 	-- disable reexecution for anything that used the plan containing the action group
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
		                        FROM [BuildExecution_DeploymentPlans] BEDP
		                             INNER JOIN [DeploymentPlanActionGroups] DPAG
		                                     ON DPAG.[DeploymentPlan_Id] = BEDP.[Original_DeploymentPlan_Id]
		                       WHERE DPAG.[ActionGroup_Id] = @ActionGroup_Id)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_UpdateActionGroup] TO [BuildMasterUser_Role]
