EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Promotions_SetAutomaticRequirementStatus',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Records the status of an automatic promotion requirement.'
GO

IF OBJECT_ID('[Promotions_SetAutomaticRequirementStatus]') IS NOT NULL DROP PROCEDURE [Promotions_SetAutomaticRequirementStatus]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Promotions_SetAutomaticRequirementStatus]
(
	@Requirement_Id INT,
	@Application_Id INT,
	@Release_Number RELEASENUMBER,
	@Build_Number BUILDNUMBER,
	@PipelineStage_Name VARCHAR(50),
	@Applicable_Indicator YNINDICATOR,
	@Met_Indicator YNINDICATOR,
	@Requirement_Description NVARCHAR(1000)
) AS BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Build_Id INT
	SELECT @Build_Id = [Build_Id]
	  FROM [Builds_Extended]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number
	   AND [Build_Number] = @Build_Number

	IF EXISTS(SELECT *
	            FROM [BuildApprovalsReceived]
			   WHERE [Build_Id] = @Build_Id
		   AND [PipelineStage_Name] = @PipelineStage_Name
				 AND [Original_Requirement_Id] = @Requirement_Id
				 AND [RequirementType_Code] IN ('AW', 'AE'))
	BEGIN


		UPDATE [BuildApprovalsReceived]
		   SET [Received_Date] = GETUTCDATE(),
		       [Comments_Text] = CASE WHEN @Applicable_Indicator = 'N' THEN 'not applicable'
                                      WHEN @Met_Indicator = 'Y' THEN 'met' 
                                 ELSE 'not met' END,
			   [Requirement_Description] = @Requirement_Description
		 WHERE [Build_Id] = @Build_Id
		   AND [PipelineStage_Name] = @PipelineStage_Name
		   AND [Original_Requirement_Id] = @Requirement_Id
		   AND [RequirementType_Code] IN ('AW', 'AE')

	END
	ELSE
	BEGIN

		INSERT INTO [BuildApprovalsReceived]
		(
			[Build_Id],
			[PipelineStage_Name],
			[Original_Requirement_Id],
			[RequirementType_Code],
			[Comments_Text],
			[Received_Date],
			[Requirement_Description]
		)
		VALUES
		(
			@Build_Id,
		    @PipelineStage_Name,
			@Requirement_Id,
			'AW',
			CASE WHEN @Applicable_Indicator = 'N' THEN 'not applicable'
                 WHEN @Met_Indicator = 'Y' THEN 'met' 
             ELSE 'not met' END,
			GETUTCDATE(),
			@Requirement_Description
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Promotions_SetAutomaticRequirementStatus] TO [BuildMasterUser_Role]